@@ -1,4 +1,5 @@
 use anyhow::{anyhow, Result};
+use core::fmt;
 use serde::{Deserialize, Serialize};
 use std::{convert::TryFrom, str::FromStr};
 
@@ -38,3 +39,13 @@ impl FromStr for Protocol {
         }
     }
 }
+
+impl fmt::Display for Protocol {
+    fn fmt(&self, f: &mut fmt::Formatter<'_>) -> fmt::Result {
+        let s = match self {
+            Protocol::Http => "http",
+            Protocol::Https => "https",
+        };
+        s.fmt(f)
+    }
+}
