@@ -44,7 +44,7 @@ fn it_can_get_multiple_deployments() {
             zone_id: ZONE_ID.to_owned(),
         }),
         DeployTarget::Zoneless(ZonelessTarget {
-            account_id: ACCOUNT_ID.to_owned(),
+            account_id: Some(ACCOUNT_ID.to_string()).into(),
             script_name: script_name.to_owned(),
         }),
     ];
@@ -66,7 +66,7 @@ fn it_can_get_a_top_level_zoneless_get_deployments() {
     let actual_deployments = manifest.get_deployments(environment).unwrap();
     let expected_deployments = vec![DeployTarget::Zoneless(ZonelessTarget {
         script_name: script_name.to_string(),
-        account_id: ACCOUNT_ID.to_string(),
+        account_id: Some(ACCOUNT_ID.to_string()).into(),
     })];
 
     assert_eq!(actual_deployments, expected_deployments);
@@ -85,20 +85,6 @@ fn it_errors_on_get_deployments_missing_name() {
     assert!(manifest.get_deployments(environment).is_err());
 }
 
-#[test]
-fn it_errors_on_get_deployments_missing_account_id() {
-    let script_name = "zoneless_no_account_id";
-    let workers_dev = true;
-    let mut test_toml = WranglerToml::zoneless(script_name, ACCOUNT_ID, workers_dev);
-    test_toml.account_id = None;
-    let toml_string = toml::to_string(&test_toml).unwrap();
-    let manifest = Manifest::from_str(&toml_string).unwrap();
-
-    let environment = None;
-
-    assert!(manifest.get_deployments(environment).is_err());
-}
-
 #[test]
 fn it_can_zoneless_get_deployments_workers_dev_false() {
     let script_name = "zoneless_false";
@@ -506,7 +492,22 @@ fn it_gets_deployments_with_route_and_workers_dev_true() {
 
     let environment = None;
 
-    assert!(manifest.get_deployments(environment).is_err());
+    let deployments = manifest.get_deployments(environment).unwrap();
+    match dbg!(&*deployments) {
+        [DeployTarget::Zoned(ZonedTarget { zone_id, routes }), DeployTarget::Zoneless(ZonelessTarget {
+            account_id: _,
+            script_name: actual_script_name,
+        })] => {
+            assert!(
+                script_name == actual_script_name
+                    && zone_id == "samplezoneid"
+                    && matches!(&**routes,
+                [Route { id: None, script: Some(actual_script_name), pattern }]
+                if script_name == actual_script_name && pattern == PATTERN)
+            );
+        }
+        _ => panic!("deployments didn't match"),
+    }
 }
 
 #[test]
@@ -522,7 +523,22 @@ fn it_gets_deployments_with_routes_and_workers_dev_true() {
 
     let environment = None;
 
-    assert!(manifest.get_deployments(environment).is_err());
+    let deployments = manifest.get_deployments(environment).unwrap();
+    match dbg!(&*deployments) {
+        [DeployTarget::Zoned(ZonedTarget { zone_id, routes }), DeployTarget::Zoneless(ZonelessTarget {
+            account_id: _,
+            script_name: actual_script_name,
+        })] => {
+            assert!(
+                script_name == actual_script_name
+                    && zone_id == "samplezoneid"
+                    && matches!(&**routes,
+                [Route { id: None, script: Some(actual_script_name), pattern }]
+                if script_name == actual_script_name && pattern == PATTERN)
+            );
+        }
+        _ => panic!("deployments didn't match"),
+    }
 }
 
 // ENVIRONMENT TESTS
@@ -589,7 +605,7 @@ fn when_top_level_empty_env_workers_dev_true() {
     let actual_deployments = manifest.get_deployments(environment).unwrap();
     let expected_deployments = vec![DeployTarget::Zoneless(ZonelessTarget {
         script_name: manifest.worker_name(environment),
-        account_id: account_id.to_string(),
+        account_id: Some(account_id.to_string()).into(),
     })];
 
     assert_eq!(actual_deployments, expected_deployments);
@@ -763,7 +779,7 @@ fn when_top_level_zoneless_env_empty() {
     let actual_deployments = manifest.get_deployments(environment).unwrap();
     let expected_deployments = vec![DeployTarget::Zoneless(ZonelessTarget {
         script_name: manifest.worker_name(environment),
-        account_id: ACCOUNT_ID.to_string(),
+        account_id: Some(ACCOUNT_ID.to_string()).into(),
     })];
 
     assert_eq!(actual_deployments, expected_deployments);
@@ -800,7 +816,7 @@ fn when_top_level_zoneless_env_zoneless_workers_dev_true() {
     let environment = Some(TEST_ENV_NAME);
     let actual_deployments = manifest.get_deployments(environment).unwrap();
     let expected_deployments = vec![DeployTarget::Zoneless(ZonelessTarget {
-        account_id: ACCOUNT_ID.to_string(),
+        account_id: Some(ACCOUNT_ID.to_string()).into(),
         script_name: manifest.worker_name(environment),
     })];
 
@@ -823,7 +839,7 @@ fn when_top_level_zoneless_env_zoned_single_route_empty() {
     let environment = Some(TEST_ENV_NAME);
     let actual_deployments = manifest.get_deployments(environment).unwrap();
     let expected_deployments = vec![DeployTarget::Zoneless(ZonelessTarget {
-        account_id: ACCOUNT_ID.to_string(),
+        account_id: Some(ACCOUNT_ID.to_string()).into(),
         script_name: manifest.worker_name(environment),
     })];
 
@@ -846,7 +862,7 @@ fn when_top_level_zoneless_env_zoned_single_route_zone_id_missing() {
     let environment = Some(TEST_ENV_NAME);
     let actual_deployments = manifest.get_deployments(Some(TEST_ENV_NAME)).unwrap();
     let expected_deployments = vec![DeployTarget::Zoneless(ZonelessTarget {
-        account_id: ACCOUNT_ID.to_string(),
+        account_id: Some(ACCOUNT_ID.to_string()).into(),
         script_name: manifest.worker_name(environment),
     })];
 
@@ -882,7 +898,7 @@ fn when_top_level_zoneless_env_zoned_single_route() {
             routes: expected_routes,
         }),
         DeployTarget::Zoneless(ZonelessTarget {
-            account_id: ACCOUNT_ID.to_string(),
+            account_id: Some(ACCOUNT_ID.to_string()).into(),
             script_name: manifest.worker_name(environment),
         }),
     ];
@@ -957,7 +973,7 @@ fn when_top_level_zoneless_env_zoned_multi_route_route_key_present() {
             zone_id: ZONE_ID.to_owned(),
         }),
         DeployTarget::Zoneless(ZonelessTarget {
-            account_id: ACCOUNT_ID.to_string(),
+            account_id: Some(ACCOUNT_ID.to_string()).into(),
             script_name: expected_name,
         }),
     ];
@@ -982,7 +998,7 @@ fn when_top_level_zoneless_env_zoned_multi_route_zone_id_missing() {
 
     let actual_deployments = manifest.get_deployments(Some(TEST_ENV_NAME)).unwrap();
     let expected_deployments = vec![DeployTarget::Zoneless(ZonelessTarget {
-        account_id: ACCOUNT_ID.to_string(),
+        account_id: Some(ACCOUNT_ID.to_string()).into(),
         script_name: manifest.worker_name(Some(TEST_ENV_NAME)),
     })];
 
@@ -1021,7 +1037,7 @@ fn when_top_level_zoneless_env_zoned_multi_route() {
             routes: expected_routes,
         }),
         DeployTarget::Zoneless(ZonelessTarget {
-            account_id: ACCOUNT_ID.to_string(),
+            account_id: Some(ACCOUNT_ID.to_string()).into(),
             script_name: expected_name,
         }),
     ];
@@ -1088,7 +1104,7 @@ fn when_top_level_zoned_env_zoneless_workers_dev_true() {
     let environment = Some(TEST_ENV_NAME);
     let actual_deployments = manifest.get_deployments(environment).unwrap();
     let expected_deployments = vec![DeployTarget::Zoneless(ZonelessTarget {
-        account_id: ACCOUNT_ID.to_string(),
+        account_id: Some(ACCOUNT_ID.to_string()).into(),
         script_name: manifest.worker_name(environment),
     })];
 
